import './assets/main.css'

import { createApp } from 'vue'
import pinia from '@/store/index'
import ElementPlus from 'element-plus'
import 'element-plus/dist/index.css'
import App from './App.vue'
import router from './router'
import * as ElementPlusIconsVue from '@element-plus/icons-vue'
import toolClass from '@/assets/js/toolClass'
import request from "@/plugin/axios/index.ts"
import "./child.ts" 

const handleGetToken = () => {
  return localStorage.getItem("token");
}

// 路由执行之前的一些操作
router.beforeEach((to, from, next) => {
  // 如果有token
  if (handleGetToken()) {
    // 是否是登录页面，直接到首页
    if (to.path === "/login") {
      next({ path: "/transmission" });
    } else {
      // 如果不是登录页面，跳转到目标的页面
      next();
    }
  } else {
    // 没有token
    if (!to.meta || !to.meta.auth) {
      // 在免登录白名单，直接进入
      next();
    } else {
      next(`/login?redirect=${to.fullPath}`); // 否则全部重定向到登录页
    }
  }
});

const app = createApp(App)
app.provide('toolClass', toolClass)
app.provide('request', request)
app.use(router)
app.use(ElementPlus)
app.use(pinia)
for (const [key, component] of Object.entries(ElementPlusIconsVue)) {
  app.component(key, component)
}

app.mount('#parentApp')
